@@ -7,7 +7,7 @@ use Encode;
 use File::Spec;
 use YAML::Tiny ();
 
-our $VERSION = '0.0.7';
+our $VERSION = '0.0.8';
 
 __PACKAGE__->setting(
     handle_static => 1,
@@ -105,6 +105,10 @@ Riji - Simple, git based blog tool
     % riji server
     % riji publish
 
+=head1 TUTORIAL
+
+L<http://songmu.github.io/p5-Riji/blog/> japanese only...
+
 =head1 DESCRIPTION
 
 Riji is a simple and git based blog tool.
